Sari | Intelligent Codebase Agent

## Indexing Engine Status

Real-time file scanning and symbol indexing
Checking...
0
Scanned Files
0
Indexed Symbols
Progress 0%

### Throughput

0.0 Docs / Sec

### System Load

CPU 0%
Memory 0GB

### Queue Depth

No active queues

### Indexed Repositories

Repository Name | Root Path | File Count | Status
--- | --- | --- | ---
Loading repositories...

Node Details
Name-
Kind-
Role-
File Path
-
Loading Graph Data...

### Settings

Settings are configured via `sari.json` or environment variables.